From 024255c6a55c9f740ce740726616dc6ff4273b06 Mon Sep 17 00:00:00 2001
From: Ariver <shanghai3168@gmail.com>
Date: Wed, 03 Jun 2026 19:41:10 +0800
Subject: [PATCH] Rename app to PrivateVoice Dictation

---
 privatevoice.src/scripts/build-release-macos.sh |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/privatevoice.src/scripts/build-release-macos.sh b/privatevoice.src/scripts/build-release-macos.sh
index 3f33265..278100f 100755
--- a/privatevoice.src/scripts/build-release-macos.sh
+++ b/privatevoice.src/scripts/build-release-macos.sh
@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 #
 # build-release-macos.sh — Build a signed & notarized macOS DMG for PrivateVoice Input
 #
 # Prerequisites (one-time):
 #   1. Install Developer ID certificate in Keychain
@@ -19,7 +19,7 @@
 IDENTITY="Developer ID Application: Ningbo Zhuozhi Innovation Network Technology Co., Ltd. (3HY4G7M2AL)"
 KEYCHAIN_PROFILE="privatevoice"
 
-APP_NAME="PrivateVoice Input"
+APP_NAME="PrivateVoice Dictation"
 BUNDLE_ID="com.privatevoice.input"
 
 SCRIPT_DIR="$(cd "$(dirname "$0")" && pwd)"
@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 #
-# build-release-macos.sh — Build a signed & notarized macOS DMG for PrivateVoice Input
+# build-release-macos.sh — Build a signed & notarized macOS DMG for PrivateVoice Dictation
 #
 # Prerequisites (one-time):

--
Gitblit v1.9.3